proc contents data=Da36498p1001;
run;

proc contents data=Da36498p2001;
run;

data indat1;
set Da36498p1001;
keep CASEID PERSONID R01X_CB_REGION R01R_A_SEX_IMP R01R_A_RACECAT3_IMP R01R_A_AGECAT7_IMP R01R_A_AM0018 R01R_A_AM0030 
R01_AM0014 R01_AX0111_01 R01_AH1002 R01R_A_AM0026 R01_AC9050 R01_AX0090 R01_AX0281 R01_AX0119_04 R01_AX0119_03
R01_AX0144 R01_AX0091 R01_AG9003 R01_AC1003 R01_AN0105_01 R01_AN0105_02 R01_AN0105_03 R01_AN0105_04;
run;

data indat12;
set indat1;

/*Demographic variables*/
sex=R01R_A_SEX_IMP;
race=R01R_A_RACECAT3_IMP;
age=R01R_A_AGECAT7_IMP;
edu=R01R_A_AM0018;
income=R01R_A_AM0030;
employ=R01_AM0014;

/*Other variables*/
insurance=R01R_A_AM0026;
Harm=R01_AC9050;
region=R01X_CB_REGION;

if R01_AN0105_01=1 or R01_AN0105_02=1 then quit_effort=1;
else if R01_AN0105_01=2 and R01_AN0105_02=2 then quit_effort=2;
else quit_effort=.;

/*Health variables*/
blood_p=R01_AX0111_01;
health=R01_AX0090;
diabetes=R01_AX0281;
asthma=R01_AX0119_04;
emphysema=R01_AX0119_03;
cancer=R01_AX0144;
mental=R01_AX0091;

/*Study variables*/
smk_hookah=R01_AH1002;
cigar=R01_AG9003;
smk_now=R01_AC1003;

keep CASEID PERSONID sex race age edu income employ insurance Harm region quit_effort
blood_p health diabetes asthma
emphysema cancer mental smk_hookah cigar smk_now;

run;

/*data check*/
proc freq data=indat12;
tables sex race age edu income employ insurance Harm region 
quit_effort blood_p health diabetes asthma
emphysema cancer mental smk_hookah cigar smk_now /missing list;
run;

proc contents data=indat12;
run;

/*missing data coding*/
data indat13;
set indat12;
sex_r=sex;
if sex<0 then sex_r=.;

race_r=race;
if race<0 then race_r=.;

age_r=age;
if age<0 then age_r=.;

edu_r=edu;
if edu<0 then edu_r=.;

income_r=income;
if income<0 then income_r=.;

employ_r=employ;
if employ<0 then employ_r=.;

insurance_r=insurance;
if insurance<0 then insurance_r=.;

harm_r=harm;
if harm<0 then harm_r=.;

region_r=region;
if region<0 then region_r=.;

quit_effort_r=quit_effort;

blood_p_r=blood_p;
if blood_p<0 then blood_p_r=.;

health_r=health;
if health<0 then health_r=.;

diabetes_r=diabetes;
if diabetes<0 then diabetes_r=.;

asthma_r=asthma;
if asthma<0 then asthma_r=.;

emphysema_r=emphysema;
if emphysema<0 then emphysema_r=.;

cancer_r=cancer;
if cancer<0 then cancer_r=.;

mental_r=mental;
if mental<0 then mental_r=.;

smk_hookah_r=smk_hookah;
if smk_hookah<0 then smk_hookah_r=.;

cigar_r=cigar;
if cigar<0 then cigar_r=.;

smk_now_r=smk_now;
if smk_now<0 then smk_now_r=.;
run;

/*Data check*/
proc freq data=indat13;
tables sex*sex_r race*race_r age*age_r edu*edu_r income*income_r employ*employ_r insurance*insurance_r 
Harm*harm_r region*region_r quit_effort*quit_effort_r blood_p*blood_p_r 
health*health_r diabetes*diabetes_r asthma*asthma_r emphysema*emphysema_r 
cancer*cancer_r mental*mental_r smk_hookah*smk_hookah_r cigar*cigar_r smk_now*smk_now_r /missing list;
run;

/*Check missingness*/
proc freq data=indat13;
tables sex_r race_r age_r edu_r income_r employ_r insurance_r 
harm_r region_r quit_effort_r blood_p_r 
health_r diabetes_r asthma_r emphysema_r 
cancer_r mental_r smk_hookah_r cigar_r smk_now_r /missing list;
run;

proc contents data=indat13;
run;

/*Step one: imputation for small missingness variables*/
proc surveyimpute data=indat13 method=HD /*varmethod=jackknife*/;
class sex_r race_r age_r edu_r employ_r insurance_r harm_r region_r blood_p_r 
health_r diabetes_r asthma_r emphysema_r cancer_r mental_r;
var sex_r race_r age_r edu_r employ_r insurance_r harm_r region_r blood_p_r 
health_r diabetes_r asthma_r emphysema_r cancer_r mental_r;
output out=outhd1;
run;

proc contents data=outhd1;
run;

proc freq data=outhd1;
tables sex_r race_r age_r edu_r income_r employ_r insurance_r 
harm_r region_r quit_effort_r blood_p_r 
health_r diabetes_r asthma_r emphysema_r 
cancer_r mental_r smk_hookah_r cigar_r smk_now_r /missing list;
run;

/*imputation for income_r quit_effort_r smk_hookah_r cigar_r smk_now_r*/
data outhd2;
set outhd1;
/*create missing indicators*/
if income_r=. then R_income=0;
else R_income=1;

if quit_effort_r=. then R_quit_effort=0;
else R_quit_effort=1;

if smk_hookah_r=. then R_smk_hookah=0;
else R_smk_hookah=1;

if smk_now_r=. then R_smk_now=0;
else R_smk_now=1;
run;

/*examine imputation model (assuming MAR)*/

proc freq data=outhd2;
tables income_r quit_effort_r smk_hookah_r cigar_r smk_now_r /missing list;
run;

%macro runlogit(vary,varx);
proc logistic data=outhd2;
class &vary.(ref="1") &varx.(ref="1") /param=ref; 
model &vary.=&varx./link=glogit;
run;
%mend runlogit;

%runlogit(income_r,sex_r);
%runlogit(income_r,race_r);
%runlogit(income_r,age_r);
%runlogit(income_r,edu_r);
%runlogit(income_r,employ_r);
%runlogit(income_r,insurance_r);
%runlogit(income_r,harm_r);
%runlogit(income_r,region_r);
%runlogit(income_r,blood_p_r);
%runlogit(income_r,health_r);
%runlogit(income_r,diabetes_r);
%runlogit(income_r,asthma_r);
%runlogit(income_r,emphysema_r);
%runlogit(income_r,cancer_r);
%runlogit(income_r,mental_r);

proc logistic data=outhd2;
class income_r(ref="1") sex_r race_r age_r edu_r employ_r insurance_r 
harm_r region_r blood_p_r 
health_r diabetes_r asthma_r emphysema_r 
cancer_r mental_r /param=ref; 
model income_r=sex_r race_r age_r edu_r employ_r insurance_r 
harm_r region_r blood_p_r 
health_r diabetes_r asthma_r emphysema_r 
cancer_r mental_r/link=glogit selection=stepwise slentry=0.3 slstay=0.35 details lackfit;
run;

%runlogit(quit_effort_r,sex_r);
%runlogit(quit_effort_r,race_r);
%runlogit(quit_effort_r,age_r);
%runlogit(quit_effort_r,edu_r);
%runlogit(quit_effort_r,employ_r);
%runlogit(quit_effort_r,insurance_r);
%runlogit(quit_effort_r,harm_r);
%runlogit(quit_effort_r,region_r);
%runlogit(quit_effort_r,blood_p_r);
%runlogit(quit_effort_r,health_r);
%runlogit(quit_effort_r,diabetes_r);
%runlogit(quit_effort_r,asthma_r);
%runlogit(quit_effort_r,emphysema_r);
%runlogit(quit_effort_r,cancer_r);
%runlogit(quit_effort_r,mental_r);

proc logistic data=outhd2;
class quit_effort_r(ref="1") sex_r race_r age_r edu_r insurance_r 
harm_r blood_p_r 
health_r diabetes_r asthma_r emphysema_r 
cancer_r mental_r /param=ref; 
model quit_effort_r=sex_r race_r age_r edu_r insurance_r 
harm_r blood_p_r 
health_r diabetes_r asthma_r emphysema_r 
cancer_r mental_r/link=glogit selection=stepwise slentry=0.3 slstay=0.35 details lackfit;
run;

/*Check missing pattern*/
proc mi data=outhd2 seed=1518971 simple nimpute=0;
      em itprint outem=outem;
      var income_r quit_effort_r smk_hookah_r cigar_r smk_now_r;
   run;

proc mi nimpute=6 data=outhd2 out=outmi1;
class sex_r race_r age_r edu_r income_r employ_r insurance_r 
harm_r region_r quit_effort_r blood_p_r 
health_r diabetes_r asthma_r emphysema_r 
cancer_r mental_r smk_hookah_r cigar_r smk_now_r;
fcs logistic(income_r) logistic(smk_hookah_r) logistic(smk_now_r) logistic(cigar_r) logistic(quit_effort_r);
var sex_r race_r age_r edu_r employ_r insurance_r harm_r region_r blood_p_r 
health_r diabetes_r asthma_r emphysema_r cancer_r mental_r income_r smk_hookah_r smk_now_r cigar_r quit_effort_r;
run;


/*****Aim1******/
proc freq data=outmi1;
tables _imputation_*income_r /nopercent norow nofreq out=out1 TOTPCT OUTPCT list;
run;

data out12;
set out1;
ste_rp=sqrt(PCT_ROW/100*(1-PCT_ROW/100)/32320);
run;

proc sort data=out12;
by income_r;
run;

proc mianalyze data=out12;
modeleffects PCT_ROW;
stderr ste_rp;
by income_r;
run ;

proc freq data=outhd2;
tables income_r;
run;

proc freq data=outmi1;
tables _imputation_*quit_effort_r /nopercent norow nofreq out=out2 TOTPCT OUTPCT list;
run;

data out22;
set out2;
ste_rp=sqrt(PCT_ROW/100*(1-PCT_ROW/100)/32320);
run;

proc sort data=out22;
by quit_effort_r;
run;

proc mianalyze data=out22;
modeleffects PCT_ROW;
stderr ste_rp;
by quit_effort_r;
run ;

proc freq data=outhd2;
tables quit_effort_r;
run;

proc freq data=outmi1;
tables _imputation_*smk_hookah_r /nopercent norow nofreq out=out3 TOTPCT OUTPCT list;
run;

data out32;
set out3;
ste_rp=sqrt(PCT_ROW/100*(1-PCT_ROW/100)/32320);
run;

proc sort data=out32;
by smk_hookah_r;
run;

proc mianalyze data=out32;
modeleffects PCT_ROW;
stderr ste_rp;
by smk_hookah_r;
run ;

proc freq data=outhd2;
tables smk_hookah_r;
run;

proc freq data=outmi1;
tables _imputation_*smk_now_r /nopercent norow nofreq out=out4 TOTPCT OUTPCT list;
run;

data out42;
set out4;
ste_rp=sqrt(PCT_ROW/100*(1-PCT_ROW/100)/32320);
run;

proc sort data=out42;
by smk_now_r;
run;

proc mianalyze data=out42;
modeleffects PCT_ROW;
stderr ste_rp;
by smk_now_r;
run ;

proc freq data=outhd2;
tables smk_now_r;
run;

proc freq data=outmi1;
tables _imputation_*cigar_r /nopercent norow nofreq out=out5 TOTPCT OUTPCT list;
run;

data out52;
set out5;
ste_rp=sqrt(PCT_ROW/100*(1-PCT_ROW/100)/32320);
run;

proc sort data=out52;
by cigar_r;
run;

proc mianalyze data=out52;
modeleffects PCT_ROW;
stderr ste_rp;
by cigar_r;
run ;

proc freq data=outhd2;
tables cigar_r;
run;

data outmi12;
set outmi1;
if smk_now_r in (1 2) then cur_smk=1;
else cur_smk=0;
run;

/***Aim2**********/
proc logistic data=outmi12;
      class sex_r race_r age_r edu_r income_r employ_r insurance_r 
harm_r region_r quit_effort_r blood_p_r 
health_r diabetes_r asthma_r emphysema_r 
cancer_r mental_r cur_smk(ref="0");
      model cur_smk(event="1")= sex_r race_r age_r edu_r income_r employ_r insurance_r 
harm_r region_r quit_effort_r blood_p_r 
health_r diabetes_r asthma_r emphysema_r 
cancer_r mental_r/ covb;
      by _Imputation_;
      ods output ParameterEstimates=lgsparms
                 CovB=lgscovb;
   run;

proc print data=lgsparms2;
run;

data logsparms2(rename=(Variable2=Variable));
set lgsparms;
Variable2=catt(Variable,ClassVal0);
drop Variable;
run;

proc contents data=logsparms2;
run;

proc mianalyze parms=logsparms2
                  covb(effectvar=stacking)=lgscovb;
      modeleffects Intercept sex_r1 race_r1 race_r2 age_r1 age_r2 age_r3 age_r4 age_r5 age_r6
edu_r1 edu_r2 edu_r3 edu_r4 edu_r5 income_r1 income_r2 income_r3 income_r4 
employ_r1 employ_r2 employ_r3 insurance_r1 insurance_r2 insurance_r3 insurance_r4 
harm_r1 harm_r2 harm_r3 harm_r4 region_r1 region_r2 region_r3 
quit_effort_r1 blood_p_r1 
health_r1 health_r2 health_r3 health_r4 diabetes_r1 asthma_r1 emphysema_r1 
cancer_r1 mental_r1 mental_r2 mental_r3 mental_r4;
   run;

/*****Aim3**************/
data indat2;
set Da36498p2001;
smk_hookah2=R02_AH1002_12M;
if R02_AH1002_12M<0 then smk_hookah2=.;
cigar2=R02_AG9003_12M;
if R02_AG9003_12M<0 then cigar2=.;
smk_now2=R02_AC1003;
if R02_AC1003<0 then smk_now2=.;
keep CASEID PERSONID smk_hookah2 cigar2 smk_now2;
run;

/*Imputation for smk_hookah2 cigar2 smk_now2*/
proc sort data=indat2;
by CASEID;
run;

proc sort data=outmi12;
by CASEID;
run;

data indat22;
merge indat2(in=A) outmi12(in=B);
by CASEID;
if A and B then resp2=1;
else if B and not A then resp2=0;
if B;
run;

/*Logistic regression of response indicator*/
proc sort data=indat22;
by _Imputation_;
run;

proc logistic data=indat22;
      class resp2(ref="0") sex_r race_r age_r edu_r income_r employ_r insurance_r 
harm_r region_r quit_effort_r blood_p_r 
health_r diabetes_r asthma_r emphysema_r 
cancer_r mental_r cigar_r smk_now_r smk_hookah_r;
      model resp2(event="1")= sex_r race_r age_r edu_r income_r employ_r insurance_r 
harm_r region_r quit_effort_r blood_p_r 
health_r diabetes_r asthma_r emphysema_r 
cancer_r mental_r cigar_r smk_now_r smk_hookah_r/ covb;
      by _Imputation_;
      ods output ParameterEstimates=lgsparms2
                 CovB=lgscovb2;
   run;

data lgsparms22(rename=(Variable2=Variable));
set lgsparms2;
Variable2=catt(Variable,ClassVal0);
drop Variable;
run;

proc mianalyze parms=lgsparms22
                  covb(effectvar=stacking)=lgscovb2;
      modeleffects Intercept sex_r1 race_r1 race_r2 age_r1 age_r2 age_r3 age_r4 age_r5 age_r6
edu_r1 edu_r2 edu_r3 edu_r4 edu_r5 income_r1 income_r2 income_r3 income_r4 
employ_r1 employ_r2 employ_r3 insurance_r1 insurance_r2 insurance_r3 insurance_r4 
harm_r1 harm_r2 harm_r3 harm_r4 region_r1 region_r2 region_r3 
quit_effort_r1 blood_p_r1 
health_r1 health_r2 health_r3 health_r4 diabetes_r1 asthma_r1 emphysema_r1 
cancer_r1 mental_r1 mental_r2 mental_r3 mental_r4 cigar_r1 smk_now_r1 smk_now_r2 smk_hookah_r1;
   run;

/*sequential imputation*/
proc freq data=indat22;
tables resp2 smk_hookah2 cigar2 smk_now2/missing list;
run;

proc sort data=indat22;
by _Imputation_;
run;

proc mi nimpute=1 data=indat22 out=outmi2;
class sex_r race_r age_r edu_r income_r employ_r insurance_r 
harm_r region_r quit_effort_r blood_p_r 
health_r diabetes_r asthma_r emphysema_r 
cancer_r mental_r smk_hookah_r cigar_r smk_now_r smk_hookah2 cigar2 smk_now2;
fcs logistic(smk_hookah2) logistic(smk_now2) logistic(cigar2);
var sex_r race_r age_r edu_r employ_r insurance_r harm_r region_r blood_p_r 
health_r diabetes_r asthma_r emphysema_r cancer_r mental_r income_r smk_hookah_r smk_now_r cigar_r quit_effort_r 
smk_hookah2 cigar2 smk_now2;
by _Imputation_;
run;

data outmi2_smk;
set outmi2;
if smk_now_r in (1 2) and smk_now2=3 then stop_smk=1;
else stop_smk=0;
where smk_now_r in (1 2);
run;

proc freq data=outmi2_smk;
tables stop_smk*smk_now_r*smk_now2 stop_smk/missing list;
run;

proc sort data=outmi2_smk;
by _Imputation_;
run;

proc logistic data=outmi2_smk;
      class stop_smk(ref="0") sex_r race_r age_r edu_r income_r employ_r insurance_r 
harm_r region_r quit_effort_r blood_p_r 
health_r diabetes_r asthma_r emphysema_r 
cancer_r mental_r cigar_r smk_now_r smk_hookah_r;
      model stop_smk(event="1")= sex_r race_r age_r edu_r income_r employ_r insurance_r 
harm_r region_r quit_effort_r blood_p_r 
health_r diabetes_r asthma_r emphysema_r 
cancer_r mental_r cigar_r smk_now_r smk_hookah_r/ covb;
      by _Imputation_;
      ods output ParameterEstimates=lgsparms3
                 CovB=lgscovb3;
   run;

data lgsparms32(rename=(Variable2=Variable));
set lgsparms3;
Variable2=catt(Variable,ClassVal0);
drop Variable;
run;

proc mianalyze parms=lgsparms32
                  covb(effectvar=stacking)=lgscovb3;
      modeleffects Intercept sex_r1 race_r1 race_r2 age_r1 age_r2 age_r3 age_r4 age_r5 age_r6
edu_r1 edu_r2 edu_r3 edu_r4 edu_r5 income_r1 income_r2 income_r3 income_r4 
employ_r1 employ_r2 employ_r3 insurance_r1 insurance_r2 insurance_r3 insurance_r4 
harm_r1 harm_r2 harm_r3 harm_r4 region_r1 region_r2 region_r3 
quit_effort_r1 blood_p_r1 
health_r1 health_r2 health_r3 health_r4 diabetes_r1 asthma_r1 emphysema_r1 
cancer_r1 mental_r1 mental_r2 mental_r3 mental_r4 cigar_r1 smk_now_r1 smk_hookah_r1;
   run;

proc logistic data=outmi2_smk;
      class stop_smk(ref="0") sex_r race_r age_r edu_r income_r employ_r insurance_r 
harm_r region_r quit_effort_r blood_p_r 
health_r diabetes_r asthma_r emphysema_r 
cancer_r mental_r cigar_r smk_now_r smk_hookah_r;
      model stop_smk(event="1")= sex_r race_r age_r edu_r income_r employ_r insurance_r 
harm_r region_r quit_effort_r blood_p_r 
health_r diabetes_r asthma_r emphysema_r 
cancer_r mental_r cigar_r smk_now_r smk_hookah_r/ covb;
      where _Imputation_=1 and resp2=1;
   run;
